@@ -1,3 +1,4 @@
+import itertools
 from .task import Task
 
 
@@ -5,10 +6,11 @@ class Job:
     def __init__(self, description):
         self._description = description
         self._tasks = [Task(t) for t in description.tasks]
+        self._on_error = [Task(t) for t in description.on_error] if description.on_error else []
 
         # Assign uniqe names to the tasks.
         used_names = set()
-        for t in self._tasks:
+        for t in itertools.chain(self._tasks, self._on_error):
             if t.name in used_names:
                 count = int(t.name.split('@')[1]) if '@' in t.name else 1
                 while True:
@@ -24,8 +26,13 @@ class Job:
         for t in self._tasks:
             yield t
 
+    @property
+    def on_error(self):
+        for t in self._on_error:
+            yield t
+
     def load_modules(self):
-        for t in self.tasks:
+        for t in itertools.chain(self.tasks, self.on_error):
             try:
                 t.load_module()
             except Exception as e:
