@@ -166,8 +166,14 @@ class Task:
                     raise ValueError(f"There are redundant fields: {unused_keys}")
                 return type_class(**c)
             elif origin is list:
+                if isinstance(value, Variable):
+                    value.expected_type = list
+                    return value
                 return [load(args[0], v) for v in value]
             elif origin is dict:
+                if isinstance(value, Variable):
+                    value.expected_type = dict
+                    return value
                 return {load(args[0], k): load(args[1], v) for k, v in value.items()}
             elif origin is typing.Union:  # Optional[X] is Union[X, NoneType]
                 if len(args) == 2 and type(None) in args:
